@@ -6,32 +6,76 @@ import os
 import warnings
 
 import numpy as np
+import numpy.core.arrayprint
 import pandas as pd
 
-""" NumPy ------------------------------------------------------------------------------- """
+""" NumPy ------------------------------------------------------------------------------------ """
 
 
-def np_preferences(reset=False):
+def np_preferences(reset=False, line_width=120, edge_items=5, decimal_digits=4):
     """
     Set preferences for displaying results.
 
+    :param line_width: number of characters per line for the purpose of inserting line breaks,
+        defaults to ``120``
+    :type line_width: int
+    :param edge_items: number of array items in summary at beginning and end of each dimension,
+        defaults to ``5``
+    :type edge_items: int
+    :param decimal_digits: number of decimal points
+    :type decimal_digits: int
     :param reset: whether to reset to default settings, defaults to ``False``
     :type reset: bool
 
     **Example**::
 
+        >>> import numpy
+
+        >>> numpy.random.seed(0)
+        >>> x = numpy.random.rand(100, 100)
+        >>> x
+        array([[0.5488135 , 0.71518937, 0.60276338, ..., 0.02010755, 0.82894003,
+                0.00469548],
+               [0.67781654, 0.27000797, 0.73519402, ..., 0.25435648, 0.05802916,
+                0.43441663],
+               [0.31179588, 0.69634349, 0.37775184, ..., 0.86219152, 0.97291949,
+                0.96083466],
+               ...,
+               [0.89111234, 0.26867428, 0.84028499, ..., 0.5736796 , 0.73729114,
+                0.22519844],
+               [0.26969792, 0.73882539, 0.80714479, ..., 0.94836806, 0.88130699,
+                0.1419334 ],
+               [0.88498232, 0.19701397, 0.56861333, ..., 0.75842952, 0.02378743,
+                0.81357508]])
+
         >>> from pyhelpers.settings import np_preferences
 
-        >>> np_preferences()
+        >>> np_preferences(decimal_digits=2)
+
+        >>> x
+        array([[0.55, 0.72, 0.60, 0.54, 0.42, ..., 0.18, 0.59, 0.02, 0.83, 0.00],
+               [0.68, 0.27, 0.74, 0.96, 0.25, ..., 0.49, 0.23, 0.25, 0.06, 0.43],
+               [0.31, 0.70, 0.38, 0.18, 0.02, ..., 0.22, 0.10, 0.86, 0.97, 0.96],
+               [0.91, 0.77, 0.33, 0.08, 0.41, ..., 0.96, 0.36, 0.36, 0.02, 0.19],
+               [0.40, 0.93, 0.10, 0.95, 0.87, ..., 0.27, 0.46, 0.40, 0.25, 0.51],
+               ...,
+               [0.03, 0.99, 0.09, 0.45, 0.84, ..., 0.12, 0.29, 0.37, 0.91, 0.14],
+               [0.62, 0.20, 0.29, 0.45, 0.55, ..., 0.48, 0.87, 0.22, 0.14, 0.93],
+               [0.89, 0.27, 0.84, 0.76, 1.00, ..., 0.98, 0.41, 0.57, 0.74, 0.23],
+               [0.27, 0.74, 0.81, 0.20, 0.31, ..., 0.51, 0.23, 0.95, 0.88, 0.14],
+               [0.88, 0.20, 0.57, 0.93, 0.56, ..., 0.55, 0.40, 0.76, 0.02, 0.81]])
     """
 
     if not reset:
-        np.core.arrayprint._line_width = 120
+        numpy.core.arrayprint._line_width = line_width
+        np.set_printoptions(linewidth=line_width, edgeitems=edge_items,
+                            formatter=dict(float=lambda x: "%.{}f".format(decimal_digits) % x))
     else:
-        np.core.arrayprint._line_width = 80  # 75
+        numpy.core.arrayprint._line_width = 80  # 75
+        np.set_printoptions(edgeitems=3, linewidth=80)
 
 
-""" Pandas ------------------------------------------------------------------------------ """
+""" Pandas ----------------------------------------------------------------------------------- """
 
 
 def pd_preferences(reset=False, ignore_future_warning=True):
@@ -40,8 +84,7 @@ def pd_preferences(reset=False, ignore_future_warning=True):
 
     :param reset: whether to reset to default settings, defaults to ``False``
     :type reset: bool
-    :param ignore_future_warning: whether to ignore/suppress future warnings,
-        defaults to ``True``
+    :param ignore_future_warning: whether to ignore/suppress future warnings, defaults to ``True``
     :type ignore_future_warning: bool
 
     **Example**::
@@ -59,7 +102,7 @@ def pd_preferences(reset=False, ignore_future_warning=True):
         pd.set_option('precision', 4)
         pd.set_option('display.max_columns', 100)
         pd.set_option('display.max_rows', 20)
-        pd.set_option('io.excel.xlsx.writer', 'xlsxwriter')
+        pd.set_option('io.excel.xlsx.writer', 'openpyxl')
         pd.set_option('mode.chained_assignment', None)
         # pandas.set_option('display.float_format', lambda x: '%.4f' % x)
     else:
@@ -68,7 +111,7 @@ def pd_preferences(reset=False, ignore_future_warning=True):
         pd.reset_option('all')
 
 
-""" Matplotlib -------------------------------------------------------------------------- """
+""" Matplotlib ------------------------------------------------------------------------------- """
 
 
 def mpl_preferences(reset=False, font_name=None):
@@ -114,7 +157,7 @@ def mpl_preferences(reset=False, font_name=None):
         plt.style.use('default')
 
 
-""" GDAL -------------------------------------------------------------------------------- """
+""" GDAL ------------------------------------------------------------------------------------- """
 
 
 def gdal_configurations(reset=False, max_tmpfile_size=5000):
@@ -143,7 +186,7 @@ def gdal_configurations(reset=False, max_tmpfile_size=5000):
         # Whether to compress nodes in temporary DB. Defaults to NO.
         gdal.SetConfigOption('OSM_COMPRESS_NODES', 'YES')
         # Maximum size in MB of in-memory temporary file.
-        # If it exceeds that value, it will go to disk. Defaults to 100.
+        #   If it exceeds that value, it will go to disk. Defaults to 100.
         gdal.SetConfigOption('OSM_MAX_TMPFILE_SIZE', str(max_tmpfile_size))
     else:
         gdal.SetConfigOption('OGR_INTERLEAVED_READING', 'NO')
